@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # coding: utf-8
 
-'''Top-level package for Pageit.'''
+'''pageit package metadata'''
 
 __author__ = 'The Metaist'
 __copyright__ = 'Copyright 2013, Metaist'
@@ -9,5 +9,5 @@ __email__ = 'metaist@metaist.com'
 __license__ = 'MIT'
 __maintainer__ = 'The Metaist'
 __status__ = 'Prototype'
-__version__ = '0.0.4'
+__version__ = '0.1.0'
 __version_info__ = tuple(__version__.split('.'))
